package com.op.wms.service;

import java.util.List;
import com.op.wms.domain.BaseBomItemsT;

/**
 * 物料BOM管理Service接口
 * 
 * @author Open Platform
 * @date 2023-07-18
 */
public interface IBaseBomItemsTService {
	/**
	 * 查询物料BOM管理
	 * 
	 * @param bomItemId 物料BOM管理主键
	 * @return 物料BOM管理
	 */
	public BaseBomItemsT selectBaseBomItemsTByBomItemId(String bomItemId);

	/**
	 * 查询物料BOM管理列表
	 * 
	 * @param baseBomItemsT 物料BOM管理
	 * @return 物料BOM管理集合
	 */
	public List<BaseBomItemsT> selectBaseBomItemsTList(BaseBomItemsT baseBomItemsT);

	/**
	 * 新增物料BOM管理
	 * 
	 * @param baseBomItemsT 物料BOM管理
	 * @return 结果
	 */
	public int insertBaseBomItemsT(BaseBomItemsT baseBomItemsT);

	/**
	 * 修改物料BOM管理
	 * 
	 * @param baseBomItemsT 物料BOM管理
	 * @return 结果
	 */
	public int updateBaseBomItemsT(BaseBomItemsT baseBomItemsT);

	/**
	 * 批量删除物料BOM管理
	 * 
	 * @param bomItemIds 需要删除的物料BOM管理主键集合
	 * @return 结果
	 */
	public int deleteBaseBomItemsTByBomItemIds(String[] bomItemIds);

	/**
	 * 删除物料BOM管理信息
	 * 
	 * @param bomItemId 物料BOM管理主键
	 * @return 结果
	 */
	public int deleteBaseBomItemsTByBomItemId(String bomItemId);
}
